n = 1000;
p = ceil(n/20);
density_D = 0.01;
quadprogOptions.MaxIter = 10000;

%% generate random problem, make sure it has a solution
exitflag = -2;
warning off
while( exitflag ~= 1)
    
    % generate random cost
    H = sparse(diag(rand(n,1)));
    f = randn(n,1);
    
    % generate equality constraints
    D = sprandn(p,n,density_D);
    d = randn(p,1);
    
    % generate inequality constraints
    F = sparse(eye(n));
    m = size(F,1);
    l = -ones(m,1);
    u = ones(m,1);
    
    
    % solve with quadprog
    tic;
    [x_quadprog,fval_quadprog,exitflag] = quadprog(H,f,[F; -F], [u; -l],D,d,[],[],[],quadprogOptions);
    quadprogtime = toc;
    
end
disp('Random feasible problem found. Calling your ECOS-based QP solver...');


%% solve with myQPsolver
[x_ecos, solvetime] = myQPsolver(H,f,F,u,l,D,d);
fprintf('QUADPROG solvetime: %6.4f seconds\n', quadprogtime);
fprintf('ECOS solvetime: %6.4f seconds\n', solvetime);


% test
fval_ecos = 0.5*(x_ecos'*H*x_ecos) + f'*x_ecos;
assert(abs(fval_ecos-fval_quadprog)/abs(fval_quadprog) < 1e-5, 'The reformulation seems to be wrong!');
disp('Congratulations, you seem to have the reformulation right!');